summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/utils.h')
-rw-r--r--kexi/formeditor/utils.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kexi/formeditor/utils.h b/kexi/formeditor/utils.h
index 30bbfdf3..3d078401 100644
--- a/kexi/formeditor/utils.h
+++ b/kexi/formeditor/utils.h
@@ -33,8 +33,8 @@ namespace KFormDesigner {
class Form;
-/*! \return tqparent object of \a o that inherits \a className or NULL if no such tqparent
- If the tqparent is found, \a prevPrev is set to a child of child of the tqparent,
+/*! \return parent object of \a o that inherits \a className or NULL if no such parent
+ If the parent is found, \a prevPrev is set to a child of child of the parent,
what for TabWidget means the page widget. */
template<class type>
type* findParent(TQT_BASE_OBJECT_NAME* o, const char* className, TQObject* &prevPrev)
@@ -42,7 +42,7 @@ type* findParent(TQT_BASE_OBJECT_NAME* o, const char* className, TQObject* &prev
if (!o || !className || className[0]=='\0')
return 0;
TQObject *prev = TQT_TQOBJECT(o);
- while ( ((o=TQT_TQOBJECT(o)->tqparent())) && !TQT_TQOBJECT(o)->inherits(className) ) {
+ while ( ((o=TQT_TQOBJECT(o)->parent())) && !TQT_TQOBJECT(o)->inherits(className) ) {
prevPrev = prev;
prev = TQT_TQOBJECT(o);
}
@@ -55,8 +55,8 @@ class KFORMEDITOR_EXPORT TabWidget : public TabWidgetBase
Q_OBJECT
TQ_OBJECT
public:
- TabWidget(TQWidget *tqparent, const char *name)
- : TabWidgetBase(tqparent, name) {}
+ TabWidget(TQWidget *parent, const char *name)
+ : TabWidgetBase(parent, name) {}
virtual ~TabWidget() {}
int tabBarHeight() const { return tabBar()->height(); }
};